package Math::Yacas;
#
# Copyright (c) 2003 Jean-Louis Morel <jl_morel@bribes.org>
#
# Version 0.01 (2003/07/10)
#
# This program is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
# GNU General Public License or the Artistic License for more details.
#
use 5.006;
use strict;
use warnings;

require Exporter;

our @ISA = qw(Exporter);

our %EXPORT_TAGS = ( 'all' => [ qw( Evaluate LastErrorMsg Output

) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(

);

our $VERSION = '0.01';

require XSLoader;
XSLoader::load('Math::Yacas', $VERSION);

1;
__END__

=head1 NAME

Math::Yacas - Perl interface to YACAS (Yet Another Computer Algebra System)

=head1 SUPPORTED PLATFORMS

=over

=item *

Windows

=back

B<Note:> If you know how to adapt this module for another platform, contact me
please (Yacas is multi-platform). For Win32 system, Yacas is provided as a
dynamically linked library; therefore it's easy to integrate it in another
application.

=head1 SYNOPSIS

  use Math::Yacas 'Evaluate';
  print Evaluate "Integrate(x) Ln(x)";  # print: x*Ln(x)-x;

=head1 DESCRIPTION

Yacas (Yet Another Computer Algebra System) is a small and highly flexible
general-purpose computer algebra system and programming language. Yacas is
multi-platform and is distributed under the GNU General Public License
(GPL). This module provides an interface to Yacas and permits to do
symbolic and numeric calculations in a Perl script.

=head2 Functions

There are only three functions: Evaluate() , Output() and LastErrorMsg() .

=over

=item Evaluate

=item $result = Evaluate( $expression );

Evaluates an expression and returns the result or undef if an error occurs.
In this case, the function LastErrorMsg() returns the error message.

=item Output

=item $string = Output();

Returns the output printed while evaluating an expression.

    use Math::Yacas ':all';

    print Evaluate "Taylor(x, 0, 5) Sin(x)";
      # prints: x-x^3/6+x^5/120;
    print "\n", Evaluate "PrettyForm(%)";
      # prints: True;
    print Output();
      # prints:      3    5
      #             x    x
      #         x - -- + ---
      #             6    120

=item LastErrorMsg

=item $message = LastErrorMsg() ;

Returns a string explaining the error if an error has occurred, or the
empty string otherwise.

=back

=head2 Exemple

A very simple script to use Yacas interactively in a console:

    #!/usr/bin/perl -w
    use strict;
    use Math::Yacas ':all';

    print "*** This is Yacas 1.0.55\nIn> ";
    while (<STDIN>) {
      chomp;
      last if $_ eq 'quit';
      next unless $_;
      my $r = Evaluate($_);
      if (defined($r)) {
        print Output() if Output();
        print "Out> $r\nIn> ";
      }
      else {
        print LastErrorMsg(), "In> ";
      }
    }

=head2 Export

None by default.

=head1 SEE ALSO

The Math::Yacas home page: http://www.bribes.org/perl/mathyacas.html

The Yacas home page : http://yacas.sourceforge.net/

Yacas documentation : http://yacas.sourceforge.net/manindex.html

=head1 AUTHOR

J-L Morel E<lt>jl_morel@bribes.orgE<gt>

=head1 COPYRIGHT

Copyright (c) 2003 J-L Morel. All rights reserved.

This program is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
